Page 82 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 82

Home

    Eight references are made to Babylon as a center of
    world commerce, much of it by maritime trade. It is
    described as, "that great city, wherein were made rich all
    that had ships in the sea by reason of her costliness"
    Revelation 18:19.

    The men of Babylon are described as merchants who
    are men of renown, "for thy merchants were the great
    men of the earth;" Revelation 18:23. Twenty-five items

    of their commerce are listed. Many items are such as
    could only be afforded by the rich. Slaves are included in
    mis list found in Revelation 18:12 & 13.

    Although the men of Babylon are described as
    outwardly powerful and wealthy businessmen, inwardly,
    they are described in some of the harshest terms found in
    Scripture. Four times the word "whore" is used and five

    Scripture, in reference to rulers or nations, they always
    referred to idolatry. For example, Ezekiel condemned the
    worship of Molech (an Ammonite god) by the nation of
    Judah in these terms, "Moreover thou hast taken thy sons
    and daughters, whom thou hast borne unto me, and these

    hast thou sacrificed unto them to be devoured. Is this thy
    whoredoms a small matter," Ezekiel 16:20. This

    Ezekiel

    16:20.

    describe idolatry, "Thou hast also committed fornication
    with the Egyptians thy neighbors," Ezekiel 16:26. The
    description of Mystery Babylon that John gave in

    77

    Mystery Babylon Unveiled

    times the word "fornication" is used.

    Whenever these terms were used in Old Testament

    whoredoms

    small matter,"

    idolatrous practice of human sacrifice was referred to as

    "whoredoms." The word "fornication" was also used to